dir_changed_since_last_scan

Function dir_changed_since_last_scan 

fn dir_changed_since_last_scan(path: &Path, cached: &DirStat) -> bool
Check if a directory or any of its subdirectories have been modified

Uses a recursive mtime comparison approach:

  1. Check if directory’s own mtime > last_scan (files/dirs added/removed)
  2. Recursively validate cached subdirectories

If files were added or removed in subdirectories, the directory mtime would have been updated by the OS.