fn get_block_size(meta: &Metadata) -> u64Expand description
Get the physical size of a file on disk in bytes
On Unix systems, this uses the blocks metadata field multiplied by 512
to get the actual disk usage, which accounts for sparse files and block alignment.
On non-Unix systems, it falls back to the logical file size.